View Source VRChat.Api.Permissions (VRChat v1.7.2)
API calls for all endpoints tagged Permissions.
Link to this section Summary
Functions
Get Assigned Permissions Returns a list of all permissions currently granted by the user. Permissions are assigned e.g. by subscribing to VRC+.
Get Permission
Returns a single permission. This endpoint is pretty useless, as it returns the exact same information as /auth/permissions.
Link to this section Functions
@spec get_assigned_permissions( Tesla.Env.client(), keyword() ) :: {:ok, [VRChat.Model.Permission.t()]} | {:ok, VRChat.Model.Error.t()} | {:error, Tesla.Env.t()}
Get Assigned Permissions Returns a list of all permissions currently granted by the user. Permissions are assigned e.g. by subscribing to VRC+.
parameters
Parameters
- connection (VRChat.Connection): Connection to server
- opts (KeywordList): [optional] Optional parameters
returns
Returns
, ...]} on success {:error, Tesla.Env.t} on failure
@spec get_permission(Tesla.Env.client(), String.t(), keyword()) :: {:ok, VRChat.Model.Permission.t()} | {:ok, VRChat.Model.Error.t()} | {:error, Tesla.Env.t()}
Get Permission
Returns a single permission. This endpoint is pretty useless, as it returns the exact same information as /auth/permissions.
parameters
Parameters
- connection (VRChat.Connection): Connection to server
- permission_id (String.t):
- opts (KeywordList): [optional] Optional parameters
returns
Returns
on success {:error, Tesla.Env.t} on failure